@@ -34,10 +34,12 @@ module Control.Monad.Logger
       MonadLogger(..)
     , MonadLoggerIO (..)
     , LogLevel(..)
+    , LogLine
     , LogSource
     -- * Re-export from fast-logger
     , LogStr
     , ToLogStr(..)
+    , fromLogStr
     -- * Helper transformers
     , LoggingT (..)
     , runStderrLoggingT
@@ -114,7 +116,7 @@ import Control.Concurrent.Chan (Chan(),writeChan,readChan)
 import Control.Concurrent.STM
 import Control.Concurrent.STM.TBChan
 import Control.Exception.Lifted (onException, bracket)
-import Control.Monad (liftM, ap, when, void, forever)
+import Control.Monad (liftM, when, void, forever)
 import Control.Monad.Base (MonadBase (liftBase), liftBaseDefault)
 #if MIN_VERSION_base(4, 9, 0)
 import qualified Control.Monad.Fail as Fail
@@ -169,8 +171,6 @@ import Control.Monad.Writer.Class ( MonadWriter (..) )
 import GHC.Stack as GHC
 #endif
 
-import Prelude hiding (catch)
-
 import Data.Conduit.Lazy (MonadActive, monadActive)
 
 data LogLevel = LevelDebug | LevelInfo | LevelWarn | LevelError | LevelOther Text
@@ -403,11 +403,20 @@ instance MonadIO m => MonadLoggerIO (NoLoggingT m) where
 
 -- | @since 0.3.26
 instance MonadUnliftIO m => MonadUnliftIO (NoLoggingT m) where
-  askUnliftIO = NoLoggingT $
-                withUnliftIO $ \u ->
-                return (UnliftIO (unliftIO u . runNoLoggingT))
+#if MIN_VERSION_unliftio_core(0, 1, 1)
+  {-# INLINE withRunInIO #-}
+  withRunInIO inner =
+    NoLoggingT $
+    withRunInIO $ \run ->
+    inner (run . runNoLoggingT)
+#else
+  askUnliftIO =
+    NoLoggingT $
+    withUnliftIO $ \u ->
+    return (UnliftIO (unliftIO u . runNoLoggingT))
+#endif
 
--- | @since 0.3.28
+-- | @since 0.3.32
 type LogLine = (Loc, LogSource, LogLevel, LogStr)
 
 -- | @since 0.3.28
@@ -625,9 +634,18 @@ instance MonadIO m => MonadLoggerIO (LoggingT m) where
 
 -- | @since 0.3.26
 instance MonadUnliftIO m => MonadUnliftIO (LoggingT m) where
-  askUnliftIO = LoggingT $ \f ->
-                withUnliftIO $ \u ->
-                return (UnliftIO (unliftIO u . flip runLoggingT f))
+#if MIN_VERSION_unliftio_core(0, 1, 1)
+  {-# INLINE withRunInIO #-}
+  withRunInIO inner =
+    LoggingT $ \r ->
+    withRunInIO $ \run ->
+    inner (run . flip runLoggingT r)
+#else
+  askUnliftIO =
+    LoggingT $ \f ->
+    withUnliftIO $ \u ->
+    return (UnliftIO (unliftIO u . flip runLoggingT f))
+#endif
 
 defaultOutput :: Handle
               -> Loc
@@ -698,10 +716,10 @@ defaultLogStrWithoutLoc loc src level msg =
 --
 -- @since 0.3.22
 runFileLoggingT :: MonadBaseControl IO m => FilePath -> LoggingT m a -> m a
-runFileLoggingT fp log = bracket
+runFileLoggingT fp logt = bracket
     (liftBase $ openFile fp AppendMode)
     (liftBase . hClose)
-    $ \h -> liftBase (hSetBuffering h LineBuffering) >> (runLoggingT log) (defaultOutput h)
+    $ \h -> liftBase (hSetBuffering h LineBuffering) >> (runLoggingT logt) (defaultOutput h)
 
 -- | Run a block using a @MonadLogger@ instance which prints to stderr.
 --
@@ -725,7 +743,7 @@ runStdoutLoggingT = (`runLoggingT` defaultOutput stdout)
 runChanLoggingT :: MonadIO m => Chan LogLine -> LoggingT m a -> m a
 runChanLoggingT chan = (`runLoggingT` sink chan)
     where
-        sink chan loc src lvl msg = writeChan chan (loc,src,lvl,msg)
+        sink chan' loc src lvl msg = writeChan chan' (loc,src,lvl,msg)
 
 -- | Read logging tuples from an unbounded channel and log them into a
 --   `MonadLoggerIO` monad, forever.
